Class: Glossarist::Pronunciation
- Inherits:
-
Lutaml::Model::Serializable
- Object
- Lutaml::Model::Serializable
- Glossarist::Pronunciation
- Defined in:
- lib/glossarist/pronunciation.rb
Overview
A pronunciation or transcription of a designation, following ISO 24229 spelling system conventions.
Each pronunciation entry specifies the text of the pronunciation and the context in which it is expressed:
-
language(ISO 639) identifies the language or dialect being pronounced -
script(ISO 15924) identifies the script used for the pronunciation text -
country(ISO 3166-1) identifies the country variant -
systemidentifies the transcription/romanization system used (ISO 24229 conversion system code or a simple identifier like “IPA”)
A designation can have multiple pronunciations, e.g.:
- IPA: { content: "toːkjoː", script: "Latn", language: "jpn", system: "IPA" }
- Hepburn: { content: "Tōkyō", script: "Latn", language: "jpn", system: "Var:jpn-Hrkt:Latn:Hepburn-1886" }
- Cyrillic: { content: "Токио", script: "Cyrl", language: "rus", system: "polivanov" }